//Source file: EndpointAddress.java
//Date: October 2006
//Service Broker Interfaces and Data Types for 3GPP TS 29.198-16 V2.0.0 Release 7

package org.csapi.jr.se.svcbroker;

/**
 * This data type defines the Tagged Choice of Data Elements that specify the address of the end point to which network traffic should be sent as a result of service interactions.
 *
 */
public final class EndpointAddress implements java.io.Serializable {

    private EndpointAddressCategory _discriminator = null;
    private java.lang.Object _object;

    /**
     * Creates a new EndpointAddress.
     * Tagged choice of data elements always have empty constructors
     */ 
    public EndpointAddress() {}

    /**
     * This method returns the discriminator.
     * 
     * @return a EndpointAddressCategory value 
     * @exception InvalidUnionAccessorException if an error occurs 
     */ 
    public EndpointAddressCategory getDiscriminator() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator == null) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return _discriminator;
    }

    /**
     * This method returns a SS7Address
     * 
     * @return  a byte[] value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public byte[] getSS7Address() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != EndpointAddressCategory.SS7_ADDRESS) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return ((byte[]) _object);
    }

    /**
     * This method sets a SS7Address
     * 
     * @param value a byte[] value
     */
    public void setSS7Address(byte[] value) {
        _discriminator = EndpointAddressCategory.SS7_ADDRESS;
        _object = value;
    }

    /**
     * This method returns a NetworkAddress
     * 
     * @return  a org.csapi.jr.se.Address value
     * @exception InvalidUnionAccessorException if an error occurs 
     */
    public org.csapi.jr.se.Address getNetworkAddress() throws org.csapi.jr.se.InvalidUnionAccessorException {
        if (_discriminator != EndpointAddressCategory.NETWORK_ADDRESS) {
            throw new org.csapi.jr.se.InvalidUnionAccessorException();
        }
        return ((org.csapi.jr.se.Address) _object);
    }

    /**
     * This method sets a NetworkAddress
     * 
     * @param value a org.csapi.jr.se.Address value
     */
    public void setNetworkAddress(org.csapi.jr.se.Address value) {
        _discriminator = EndpointAddressCategory.NETWORK_ADDRESS;
        _object = value;
    }


    /**
     * This method will receive the discriminator as a parameter and will set _object to null
     * 
     * @param discriminator a EndpointAddressCategory value 
     */ 
    public void setUndefined(EndpointAddressCategory discriminator) {
        _discriminator = discriminator;
        _object = null;
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) {
            return false;
        }
        if(!(o instanceof EndpointAddress)) {
            return false;
        } else {
            EndpointAddress endpointAddress= (EndpointAddress)o;
            if(!(this._object.equals(endpointAddress._object))){
                return false;
            } else {
                if(!(this._discriminator.equals(endpointAddress._discriminator))){
                    return false;
                }
            }
            if (this.hashCode() != o.hashCode()) {
                return false;
            }
            return true;
        }
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // EndpointAddress

