//Source file: EndpointAddressCategory.java
//Date: October 2006
//Service Broker Interfaces and Data Types for 3GPP TS 29.198-16 V2.0.0 Release 7

package org.csapi.jr.se.svcbroker;

/**
 * 
 *
 */
public final class EndpointAddressCategory implements java.io.Serializable {

    private int _value;
    private static int _size = 2;
    private static EndpointAddressCategory[] _array = new EndpointAddressCategory[_size];

    /**
     * Private constructor used internally to construct static objects 
     */
    private EndpointAddressCategory(int value) {
        _value = value;
        _array[_value] = this;
    }

    /**
     * Network address for protocol specific traffic
     */
    public static final int _NETWORK_ADDRESS =  0;

    /**
     * Network address for protocol specific traffic
     */
    public static final EndpointAddressCategory NETWORK_ADDRESS = new EndpointAddressCategory(_NETWORK_ADDRESS);

    /**
     * SS7 Address for endpoint. For example, encoded Global Title or Point Code with SSN as specified in ITU-T Q.713
     */
    public static final int _SS7_ADDRESS =  1;

    /**
     * SS7 Address for endpoint. For example, encoded Global Title or Point Code with SSN as specified in ITU-T Q.713
     */
    public static final EndpointAddressCategory SS7_ADDRESS = new EndpointAddressCategory(_SS7_ADDRESS);


    /**
     * Method allows class to replace/resolve the object read from the stream before it 
     * is returned to the caller. By implementing this method, a class can directly control
     * the types and instances of its own instances being deserialized.
     *
     * @return the resolved EndpointAddressCategory object 
     */
    private Object readResolve() throws java.io.ObjectStreamException {
        return _array[_value];
    }

    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * getValueText method, overrides the getValueText() method in class java.lang.Object
     *
     * @return String  The stringified version of the EndpointAddressCategory object
     */
    public String getValueText() {
        switch (_value) {
            case _NETWORK_ADDRESS:
                return "NETWORK_ADDRESS";
            case _SS7_ADDRESS:
                return "SS7_ADDRESS";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 1
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static EndpointAddressCategory getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException("value [" + value +" ] out of range");
        }
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof EndpointAddressCategory)) {
            return false;
        }
        EndpointAddressCategory endpointAddressCategory = (EndpointAddressCategory) o; 
        if(!(this.getValue() == endpointAddressCategory.getValue())) {
            return false;
        }
        if (this.hashCode() != endpointAddressCategory.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // EndpointAddressCategory

